@@ -10,5 +10,7 @@ python_major_version = version_info.major
 
 if python_major_version == 3:
     from ttp.ttp import ttp
+    from ttp.utils.quick_parse import quick_parse
 elif python_major_version == 2:
     from ttp import ttp
+    from utils.quick_parse import quick_parse
