@@ -1,14 +1,17 @@
 import logging
+
 log = logging.getLogger(__name__)
 
+
 def str_to_unicode(data):
-    if _ttp_["python_major_version"] == 3:
+    if _ttp_["python_major_version"] == 3:  # pylint: disable=undefined-variable
         return data, None
     for key, value in data.items():
         if isinstance(value, str):
-            data[key] = unicode(value)
+            data[key] = unicode(value)  # pylint: disable=undefined-variable
     return data, None
-    
+
+
 def to_int(data, *keys):
     if not keys:
         keys = list(data.keys())
@@ -21,4 +24,4 @@ def to_int(data, *keys):
                 data[k] = float(v)
             except:
                 continue
-    return data, None
\ No newline at end of file
+    return data, None
