@@ -6,8 +6,9 @@ _name_map_ = {"dns_forward": "dns", "dns_reverse": "rdns"}
 dns_resolver_obj = dnspython.dns.resolver.Resolver()
 
 
-def dns_forward(data, record="A", timeout=1, servers=[], add_field=False):
+def dns_forward(data, record="A", timeout=1, servers=None, add_field=False):
     """Performs forward dns lookup using dns_resolver_obj global object"""
+    servers = servers or []
     dns_resolver_obj.timeout = timeout
     if servers:
         if isinstance(servers, str):
@@ -31,10 +32,11 @@ def dns_forward(data, record="A", timeout=1, servers=[], add_field=False):
     return data, None
 
 
-def dns_reverse(data, timeout=1, servers=[], add_field=False):
+def dns_reverse(data, timeout=1, servers=None, add_field=False):
     """Performs reverse dns lookup using global dns_resolver_obj
     data - ip address string, e.g. 192.168.0.1
     """
+    servers = servers or []
     dns_resolver_obj.timeout = timeout
     if servers:
         if isinstance(servers, str):
